Stan Math Library: stan/math/prim/mat/meta/index_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

index_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_INDEX_TYPE_HPP
2 #define STAN_MATH_PRIM_MAT_META_INDEX_TYPE_HPP
3
4 #include <stan/math/prim/scal/meta/index_type.hpp>
5 #include <Eigen/Core>
6
7 namespace stan {
8
9 namespace math {
10
19 template <typename T, int R, int C>
20 struct index_type<Eigen::Matrix<T, R, C> > {
21 typedef typename Eigen::Matrix<T, R, C>::Index type;
22 };
23
24
25 }
26
27 }
28
29
30 #endif
index_type.hpp
stan
Definition: log_sum_exp.hpp:8
Eigen
(Expert) Numerical traits for algorithmic differentiation variables.
Definition: Eigen_NumTraits.hpp:8
stan::math::index_type
Primary template class for the metaprogram to compute the index type of a container.
Definition: index_type.hpp:19
stan::math::index_type< Eigen::Matrix< T, R, C > >::type
Eigen::Matrix< T, R, C >::Index type
Definition: index_type.hpp:21

[ Stan Home Page ] © 2011–2016, Stan Development Team.